cpsportlets_navigation_display_voc_vocabulary = {
    'data': {
        'tuples': (
            ('navigation_tree', 'Navigation tree',
             'cpsportlets_nav_display_navtree_menu_label'),
            ('folder_contents', 'Folder contents',
             'cpsportlets_nav_display_folder_contents_menu_label'),
            ('folder_contents_dropdown_list', 'Folder contents (drop-down list)',
             'cpsportlets_nav_display_folder_contents_dropdown_list_label'),
            ('collapsible_menu', 'Collapsible menu',
             'cpsportlets_nav_display_collapsible_menu_label'),
            ('site_map', 'Site map',
             'cpsportlets_nav_display_site_map_label'),
            ('extended_site_map', 'Extended site map',
             'cpsportlets_nav_display_extended_site_map_label'),
            ('vertical_breadcrumbs_menu', 'Vertical breadcrumbs menu',
             'cpsportlets_nav_display_vertical_breadcrumbs_menu_label'),
            ('subfolder_contents', 'Sub-folder contents',
             'cpsportlets_nav_display_subfolder_contents_menu_label'),
            ('up_to_parent', 'Up to parent folder',
             'cpsportlets_nav_display_up_to_parent_label'),
        ),
    },
}

vocabularies = {'cpsportlets_navigation_display_voc': cpsportlets_navigation_display_voc_vocabulary,
               }
return vocabularies
